/**************************************************************************//**
 * @file     system_Z32F3841.c
 * @brief    CMSIS Cortex-M3 Device Peripheral Access Layer Source File for
 *           Device Z32F3841
 * @version  V3.10
 * @date     01. August 2015
 *
 * @note
 *
 ******************************************************************************/
/* Copyright (c) 2012 ARM LIMITED

   All rights reserved.
   Redistribution and use in source and binary forms, with or without
   modification, are permitted provided that the following conditions are met:
   - Redistributions of source code must retain the above copyright
     notice, this list of conditions and the following disclaimer.
   - Redistributions in binary form must reproduce the above copyright
     notice, this list of conditions and the following disclaimer in the
     documentation and/or other materials provided with the distribution.
   - Neither the name of ARM nor the names of its contributors may be used
     to endorse or promote products derived from this software without
     specific prior written permission.
   *
   THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
   AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
   IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
   ARE DISCLAIMED. IN NO EVENT SHALL COPYRIGHT HOLDERS AND CONTRIBUTORS BE
   LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
   CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
   SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
   INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
   CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
   ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
   POSSIBILITY OF SUCH DAMAGE.
   ---------------------------------------------------------------------------*/

#include "Z32F3841.h"

/*----------------------------------------------------------------------------
  DEFINES
 *----------------------------------------------------------------------------*/
uint32_t SystemCoreClock;     /*!< System Clock Frequency (Core Clock)  HLCK */
uint32_t SystemPeriClock;     /*!< System Clock Frequency (Peri Clock)  PCLK */
/*----------------------------------------------------------------------------
  Clock functions
 *----------------------------------------------------------------------------*/

/**
 * Initialize the system
 *
 * @param  none
 * @return none
 *
 * @brief  Setup the microcontroller system.
 *         Initialize the System.
 */
void SystemInit (void)
{
	uint8_t reg_val8;
	uint32_t i;
	
/* ToDo: add code to initialize the system
         do not use global variables because this function is called before
         reaching pre-main. RW section maybe overwritten afterwards.          */

	WDT->CON = 0; // disable WDT ;default ON so you must turn off


	SCB->VTOR = 0x00000000; //Vector Table Offset Register
	
	SystemCoreClock=1000000; //1Mhz

// enable internal osc clock [IOSC=20Mhz] ; !!! you must enable IOSC. if not, you cannot change MOSC. !!!
	reg_val8=SCU->CSCR;
	reg_val8&=~(3<<2); // 
	reg_val8|=(2<<2); // 0,1:Stop internal oscillator, 2:Enable internal oscillator (20Mhz), 3:Enable internal oscillator divide by 2 (10Mhz)
	SCU->CSCR=reg_val8;	

	for (i=0;i<100;i++); // IOSC stable time 
	
// ROSC(1Mhz) --> IOSC 
	reg_val8=SCU->SCCR;
	reg_val8&=~(7<<0); //
	reg_val8|=((0<<2)|(2<<0));  //FINSEL[2] - 0:IOSC, 1:MOSC(external crystal)
	                                           //MCLKSEL[1:0] -  0,1:Internal sub oscillator(ROSC), 2:PLL bypassed clock, 3:PLL output clock
	SCU->SCCR=reg_val8;	
	
	SystemCoreClock=20000000; //20Mhz
	SystemPeriClock=20000000; //20Mhz
	

}



