;/**************************************************************************//**
; * @file     startup_Z32F1281.s
; * @brief    CMSIS Cortex-M3 Core Device Startup File for
; *           Device Z32F1281 using IAR
; * @version  V3.10
; * @date     01. August 2015
; *
; * @note
; *
; ******************************************************************************/
;/* Copyright (c) 2012 ARM LIMITED
;
;   All rights reserved.
;   Redistribution and use in source and binary forms, with or without
;   modification, are permitted provided that the following conditions are met:
;   - Redistributions of source code must retain the above copyright
;     notice, this list of conditions and the following disclaimer.
;   - Redistributions in binary form must reproduce the above copyright
;     notice, this list of conditions and the following disclaimer in the
;     documentation and/or other materials provided with the distribution.
;   - Neither the name of ARM nor the names of its contributors may be used
;     to endorse or promote products derived from this software without
;     specific prior written permission.
;   *
;   THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
;   AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
;   IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
;   ARE DISCLAIMED. IN NO EVENT SHALL COPYRIGHT HOLDERS AND CONTRIBUTORS BE
;   LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
;   CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
;   SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
;   INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
;   CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
;   ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
;   POSSIBILITY OF SUCH DAMAGE.
;   ---------------------------------------------------------------------------*/
;/*
;//-------- <<< Use Configuration Wizard in Context Menu >>> ------------------
;*/


        MODULE  ?cstartup

        ;; Forward declaration of sections.
        SECTION CSTACK:DATA:NOROOT(3)

        SECTION .intvec:CODE:NOROOT(2)

        EXTERN  __iar_program_start
        EXTERN  SystemInit
        PUBLIC  __vector_table
        PUBLIC	__vector_table_0x1C
        PUBLIC	__Vectors
        PUBLIC	__Vectors_End
        PUBLIC	__Vectors_Size

        DATA

__vector_table
		        DCD     sfe(CSTACK)              ; Top of Stack
                DCD     Reset_Handler             ; Reset Handler
                DCD     NMI_Handler               ; NMI Handler
                DCD     HardFault_Handler         ; Hard Fault Handler
                DCD     MemManage_Handler         ; MPU Fault Handler
                DCD     BusFault_Handler          ; Bus Fault Handler
                DCD     UsageFault_Handler        ; Usage Fault Handler
__vector_table_0x1C              
                DCD     0                         ; Reserved
                DCD     0                         ; Reserved
                DCD     0                         ; Reserved
                DCD     0                         ; Reserved
                DCD     SVC_Handler               ; SVCall Handler
                DCD     DebugMon_Handler          ; Debug Monitor Handler
                DCD     0                         ; Reserved
                DCD     PendSV_Handler            ; PendSV Handler
                DCD     SysTick_Handler           ; SysTick Handler

                ; External Interrupts
; ToDo:  Add here the vectors for the device specific external interrupts handler
		DCD	LVDDETECT_IRQHandler						;0
		DCD	SYSCLKFAIL_IRQHandler					;1
		DCD	XOSCFAIL_IRQHandler						;2
		DCD	WDT_IRQHandler							;3
		DCD	FRT_IRQHandler							;4
		DCD	TIMER0_IRQHandler						;5
		DCD	TIMER1_IRQHandler						;6
		DCD	TIMER2_IRQHandler						;7
		DCD	TIMER3_IRQHandler						;8
		DCD	TIMER4_IRQHandler						;9
		DCD	TIMER5_IRQHandler						;10
		DCD	TIMER6_IRQHandler						;11
		DCD	TIMER7_IRQHandler						;12
		DCD	TIMER8_IRQHandler						;13
		DCD	TIMER9_IRQHandler						;14
		DCD	NULL_IRQHandler							;15
		DCD	GPIOAE_IRQHandler						;16
		DCD	GPIOAO_IRQHandler						;17
		DCD	GPIOBE_IRQHandler						;18
		DCD	GPIOBO_IRQHandler						;19
		DCD	GPIOCE_IRQHandler						;20
		DCD	GPIOCO_IRQHandler						;21
		DCD	GPIODE_IRQHandler						;22
		DCD	GPIODO_IRQHandler						;23
		DCD	MPWM0_IRQHandler						;24
		DCD	MPWM0PROT_IRQHandler					;25
		DCD	MPWM0OVV_IRQHandler					;26
		DCD	MPWM1_IRQHandler						;27
		DCD	MPWM1PROT_IRQHandler					;28
		DCD	MPWM1OVV_IRQHandler					;29
		DCD	NULL_IRQHandler							;30
		DCD	NULL_IRQHandler							;31
		DCD	SPI0_IRQHandler							;32
		DCD	SPI1_IRQHandler							;33
		DCD	NULL_IRQHandler							;34
		DCD	NULL_IRQHandler							;35
		DCD	I2C0_IRQHandler							;36
		DCD	I2C1_IRQHandler							;37
		DCD	UART0_IRQHandler						;38
		DCD	UART1_IRQHandler						;39
		DCD	UART2_IRQHandler						;40
		DCD	UART3_IRQHandler						;41
		DCD	NULL_IRQHandler							;42	
		DCD	ADC0_IRQHandler							;43
		DCD	ADC1_IRQHandler							;44
		DCD	NULL_IRQHandler							;45
		DCD	NULL_IRQHandler							;46
		DCD	NULL_IRQHandler							;47
		DCD	NULL_IRQHandler							;48
		DCD	NULL_IRQHandler							;49
		DCD	GPIOEE_IRQHandler						;50
		DCD	GPIOEO_IRQHandler						;51
		DCD	GPIOFE_IRQHandler						;52
		DCD	GPIOFO_IRQHandler						;53
		DCD	NULL_IRQHandler							;54
		DCD	NULL_IRQHandler							;55
		DCD	NULL_IRQHandler							;56
		DCD	NULL_IRQHandler							;57
		DCD	NULL_IRQHandler							;58
		DCD	NULL_IRQHandler							;59
		DCD	NULL_IRQHandler							;60
		DCD	NULL_IRQHandler							;61
		DCD	NULL_IRQHandler							;62
		DCD	NULL_IRQHandler							;63                
__Vectors_End
__Vectors		EQU		__vector_table
__Vectors_Size  EQU     __Vectors_End - __Vectors

;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;	
;;  Default interrupt handlers
;;
        THUMB

        PUBWEAK Reset_Handler
        SECTION .text:CODE:REORDER:NOROOT(2)
Reset_Handler

        LDR     R0, =SystemInit
        BLX     R0
        LDR     R0, =__iar_program_start
        BX      R0

        PUBWEAK NMI_Handler
        SECTION .text:CODE:REORDER:NOROOT(1)
NMI_Handler
        B NMI_Handler

        PUBWEAK HardFault_Handler
        SECTION .text:CODE:REORDER:NOROOT(1)
HardFault_Handler
        B HardFault_Handler

        PUBWEAK MemManage_Handler
        SECTION .text:CODE:REORDER:NOROOT(1)
MemManage_Handler
        B MemManage_Handler

        PUBWEAK BusFault_Handler
        SECTION .text:CODE:REORDER:NOROOT(1)
BusFault_Handler
        B BusFault_Handler

        PUBWEAK UsageFault_Handler
        SECTION .text:CODE:REORDER:NOROOT(1)
UsageFault_Handler
        B UsageFault_Handler

        PUBWEAK SVC_Handler
        SECTION .text:CODE:REORDER:NOROOT(1)
SVC_Handler
        B SVC_Handler

        PUBWEAK DebugMon_Handler
        SECTION .text:CODE:REORDER:NOROOT(1)
DebugMon_Handler
        B DebugMon_Handler

        PUBWEAK PendSV_Handler
        SECTION .text:CODE:REORDER:NOROOT(1)
PendSV_Handler
        B PendSV_Handler

        PUBWEAK SysTick_Handler
        SECTION .text:CODE:REORDER:NOROOT(1)
SysTick_Handler
        B SysTick_Handler

; Device Specific Handlers

;Null Handler - for Interrupts that don't exist
	PUBWEAK NULL_IRQHandler
        SECTION .text:CODE:REORDER:NOROOT(1)
NULL_IRQHandler 
	B NULL_IRQHandler

; External Interrupts

	PUBWEAK LVDDETECT_IRQHandler
        SECTION .text:CODE:REORDER:NOROOT(1)
LVDDETECT_IRQHandler
	B LVDDETECT_IRQHandler
		
	PUBWEAK SYSCLKFAIL_IRQHandler
        SECTION .text:CODE:REORDER:NOROOT(1)
SYSCLKFAIL_IRQHandler
	B SYSCLKFAIL_IRQHandler
		
	PUBWEAK XOSCFAIL_IRQHandler   		        
        SECTION .text:CODE:REORDER:NOROOT(1)
XOSCFAIL_IRQHandler
	B XOSCFAIL_IRQHandler

	PUBWEAK WDT_IRQHandler   		
        SECTION .text:CODE:REORDER:NOROOT(1)
WDT_IRQHandler	
	B .

	PUBWEAK FRT_IRQHandler   		
        SECTION .text:CODE:REORDER:NOROOT(1)
FRT_IRQHandler	
	B .	
			
	PUBWEAK TIMER0_IRQHandler      
        SECTION .text:CODE:REORDER:NOROOT(1)
TIMER0_IRQHandler	
 	B .

	PUBWEAK TIMER1_IRQHandler      
	SECTION .text:CODE:REORDER:NOROOT(1)
TIMER1_IRQHandler	
  	B .

	PUBWEAK TIMER2_IRQHandler      
	SECTION .text:CODE:REORDER:NOROOT(1)
TIMER2_IRQHandler	
 	B .
			
	PUBWEAK TIMER3_IRQHandler      
	SECTION .text:CODE:REORDER:NOROOT(1)
TIMER3_IRQHandler	
  	B .
		
	PUBWEAK TIMER4_IRQHandler      
	SECTION .text:CODE:REORDER:NOROOT(1)
TIMER4_IRQHandler	
 	B .
 					
	PUBWEAK TIMER5_IRQHandler      
	SECTION .text:CODE:REORDER:NOROOT(1)
TIMER5_IRQHandler	
 	B .
	
	PUBWEAK TIMER6_IRQHandler      
	SECTION .text:CODE:REORDER:NOROOT(1)
TIMER6_IRQHandler	
 	B .
 
 	PUBWEAK TIMER7_IRQHandler      
	SECTION .text:CODE:REORDER:NOROOT(1)
TIMER7_IRQHandler	
 	B .
 		
 	PUBWEAK TIMER8_IRQHandler      
	SECTION .text:CODE:REORDER:NOROOT(1)
TIMER8_IRQHandler	
 	B .
 		
 	PUBWEAK TIMER9_IRQHandler      
	SECTION .text:CODE:REORDER:NOROOT(1)
TIMER9_IRQHandler	
 	B .
 											
       PUBWEAK GPIOAE_IRQHandler      
       SECTION .text:CODE:REORDER:NOROOT(1)
GPIOAE_IRQHandler	
 	B .
			
	PUBWEAK GPIOAO_IRQHandler      
        SECTION .text:CODE:REORDER:NOROOT(1)
GPIOAO_IRQHandler	
 	B .
			
	PUBWEAK GPIOBE_IRQHandler      
	SECTION .text:CODE:REORDER:NOROOT(1)
GPIOBE_IRQHandler	
  	B .
			
	PUBWEAK GPIOBO_IRQHandler      
        SECTION .text:CODE:REORDER:NOROOT(1)
GPIOBO_IRQHandler	
 	B .
			
	PUBWEAK GPIOCE_IRQHandler      
        SECTION .text:CODE:REORDER:NOROOT(1)
GPIOCE_IRQHandler	
 	B .
			
	PUBWEAK GPIOCO_IRQHandler      
        SECTION .text:CODE:REORDER:NOROOT(1)
GPIOCO_IRQHandler	
	B .
			
	PUBWEAK GPIODE_IRQHandler      
        SECTION .text:CODE:REORDER:NOROOT(1)
GPIODE_IRQHandler	
	B .
			
	PUBWEAK GPIODO_IRQHandler      
        SECTION .text:CODE:REORDER:NOROOT(1)
GPIODO_IRQHandler	
	B .
			
	PUBWEAK GPIOEE_IRQHandler      
        SECTION .text:CODE:REORDER:NOROOT(1)
GPIOEE_IRQHandler	
	B .
			
	PUBWEAK GPIOEO_IRQHandler      
        SECTION .text:CODE:REORDER:NOROOT(1)
GPIOEO_IRQHandler	
	B .

	PUBWEAK GPIOFE_IRQHandler      
        SECTION .text:CODE:REORDER:NOROOT(1)
GPIOFE_IRQHandler	
	B .
			
	PUBWEAK GPIOFO_IRQHandler      
        SECTION .text:CODE:REORDER:NOROOT(1)
GPIOFO_IRQHandler	
	B .
			
	PUBWEAK MPWM0_IRQHandler       
        SECTION .text:CODE:REORDER:NOROOT(1)
MPWM0_IRQHandler	
	B .

	PUBWEAK MPWM0PROT_IRQHandler   
        SECTION .text:CODE:REORDER:NOROOT(1)
MPWM0PROT_IRQHandler
	B .

	PUBWEAK MPWM0OVV_IRQHandler  
        SECTION .text:CODE:REORDER:NOROOT(1)
MPWM0OVV_IRQHandler
	B .
			
	PUBWEAK MPWM1_IRQHandler
        SECTION .text:CODE:REORDER:NOROOT(1)
MPWM1_IRQHandler	
	B .

	PUBWEAK MPWM1PROT_IRQHandler   
        SECTION .text:CODE:REORDER:NOROOT(1)
MPWM1PROT_IRQHandler
	B .

	PUBWEAK MPWM1OVV_IRQHandler    
        SECTION .text:CODE:REORDER:NOROOT(1)
MPWM1OVV_IRQHandler
	B .

	PUBWEAK SPI0_IRQHandler   			
        SECTION .text:CODE:REORDER:NOROOT(1)
SPI0_IRQHandler	
	B .
			
	PUBWEAK SPI1_IRQHandler   
        SECTION .text:CODE:REORDER:NOROOT(1)
SPI1_IRQHandler	
	B .
		
	PUBWEAK I2C0_IRQHandler        
        SECTION .text:CODE:REORDER:NOROOT(1)
I2C0_IRQHandler	
	B .
	
	PUBWEAK I2C1_IRQHandler        
        SECTION .text:CODE:REORDER:NOROOT(1)
I2C1_IRQHandler	
	B .
			
	PUBWEAK UART0_IRQHandler       
        SECTION .text:CODE:REORDER:NOROOT(1)
UART0_IRQHandler	
	B .
			
	PUBWEAK UART1_IRQHandler       
        SECTION .text:CODE:REORDER:NOROOT(1)
UART1_IRQHandler	
	B .
			
	PUBWEAK UART2_IRQHandler       
        SECTION .text:CODE:REORDER:NOROOT(1)
UART2_IRQHandler	
	B .
			
	PUBWEAK UART3_IRQHandler       
        SECTION .text:CODE:REORDER:NOROOT(1)
UART3_IRQHandler	
	B .
			
	PUBWEAK ADC0_IRQHandler       
        SECTION .text:CODE:REORDER:NOROOT(1)
ADC0_IRQHandler	
	B .

	PUBWEAK ADC1_IRQHandler       
        SECTION .text:CODE:REORDER:NOROOT(1)
ADC1_IRQHandler	
	B .

	END	
                
;/*************  END OF FILE  **************************************/
